#
# spec file for package python-tornado
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without python2
%{?sle15_python_module_pythons}
%global mbflavor python3%{nil}
%if "%{mbflavor}" == "python2" && 0%{with python2}
# TW Factory defines _without_python2 and skips all python3 flavors if skip_python3 is defined
%define skip_python3 1
%define tornadoN tornado5
%define flavorbuild 1
%endif
%if "%{mbflavor}" == "python3"
# All distributions should have one or more python3 flavors
%define skip_python2 1
%define tornadoN tornado6
%define flavorbuild 1
%endif
%if ! 0%{?flavorbuild}
ExclusiveArch:  DoNotBuild
%endif

# query the default provider and assume that all installed python flavors have the same version
%if %{defined sle15_python_module_pythons}
%define Nversion %(rpm -q --qf '%%{version}' --whatprovides %{pythons}-%{tornadoN})
%else
%define Nversion %(rpm -q --qf '%%{version}' --whatprovides %{mbflavor}-%{tornadoN})
%endif

Name:           python-tornado
Version:        %{Nversion}
Release:        17.4
Summary:        A Python web framework and asynchronous networking library
License:        Apache-2.0
URL:            https://www.tornadoweb.org
Source0:        README.SUSE
BuildRequires:  %{python_module %{tornadoN}}
BuildRequires:  python-rpm-macros
Requires:       python-%{tornadoN} = %{Nversion}
BuildArch:      noarch
%python_subpackages

%description
Tornado is a Python web framework and asynchronous networking library,
originally developed at FriendFeed. By using non-blocking network I/O, Tornado
can scale to tens of thousands of open connections, making it ideal for long
polling, WebSockets, and other applications that require a long-lived
connection to each user.

%prep
%setup -q -T -c
cp %{SOURCE0} .

%build
:

%install
:

%files %{python_files}
%doc README.SUSE

%changelog
* Tue Nov  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Avoid using requires_eq, which after the last modifications
  conflicts with python singlespec (order of expansion).
* Mon Apr 24 2023 Daniel Garcia <daniel.garcia@suse.com>
- Do not hardcode the python version to get the python-tornadoN
  version.
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Feb  8 2021 Ben Greiner <code@bnavigator.de>
- Multibuild and singlespec again: remove a lot of duplicated code
- Get the correct tornado6 version from the installed package at
  buildtime.
* Sat Jan 30 2021 Ben Greiner <code@bnavigator.de>
- Make packages for python36 and python38 in Tumbleweed
* Wed Apr  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add conditional so we can dynamically turn off python2
* Tue Oct  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Require tornado5 for py2 and tornado6 for py3 as they
  are in different versions
- Also switch from singlespec to explicit writeup for the obvious
  distinction between different versions of 2 and 3 variant
* Wed Aug 14 2019 Todd R <toddrme2178@gmail.com>
- Switch to tornado 4 temporarily.
* Fri Aug  9 2019 Todd R <toddrme2178@gmail.com>
- Fix package name
* Fri Aug  9 2019 Todd R <toddrme2178@gmail.com>
- Split tornado versions into their own packages.
  This package now depends on the current preferred version.
- Remove patches since there is no longer a source here:
  * asyncio.patch
  * openssl-cert-size.patch
  * skip-failing-tests.patch
  * tornado-testsuite_timeout.patch
* Thu Mar  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes macro expansion
* Wed Jan 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to skip tests failing with openss-1.1.1; this happens
  only when using TLS 1.3 so if user wants to use tornado they
  can hand disable the TLS and continue:
  * skip-failing-tests.patch
* Mon Jan 28 2019 Jonathan Brownell <jbrownell@suse.com>
- Import necessary dependencies on Red Hat platforms
* Thu Jan 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch really fixing the tests/tool to work on py3.7:
  * asyncio.patch
- Add patch to enlarge key size for openssl 1.1.1:
  * openssl-cert-size.patch
* Thu Jan 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop patch tornado-async-deprecations.patch that does not fix
  stuff on py3.7
* Thu May 10 2018 toddrme2178@gmail.com
- Fix building on SLE
* Wed Apr 18 2018 toddrme2178@gmail.com
- Don't require backport_abc for python >= 3.5
* Fri Mar 16 2018 ro@suse.de
- add tornado-testsuite_timeout.patch (bsc#1085661)
  extend timeouts in testsuite to allow successful build on ppc64le
* Wed Mar  7 2018 aplanas@suse.com
- Allows Recommends and Suggest in Fedora
* Tue Feb 27 2018 aplanas@suse.com
- Recommends only for SUSE
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update to version 4.5.3
  + tornado.curl_httpclient
  * Improved debug logging on Python 3.
  + tornado.httpserver
  * ``Content-Length`` and ``Transfer-Encoding`` headers are no longer
    sent with 1xx or 204 responses (this was already true of 304
    responses).
  * Reading chunked requests no longer leaves the connection in a broken
    state.
  + tornado.iostream
  * Writing a `memoryview` can no longer result in "BufferError:
    Existing exports of data: object cannot be re-sized".
  + tornado.options
  * Duplicate option names are now detected properly whether they use
    hyphens or underscores.
  + tornado.testing
  * `.AsyncHTTPTestCase.fetch` now uses ``127.0.0.1`` instead of
    ``localhost``, improving compatibility with systems that have
    partially-working ipv6 stacks.
  + tornado.web
  * It is no longer allowed to send a body with 1xx or 204 responses.
  + tornado.websocket
  * Requests with invalid websocket headers now get a response with
    status code 400 instead of a closed connection.
* Thu Jan  4 2018 jmatejek@suse.com
- only buildrequire futures / singledispatch if python2 is present
  (fixes build in environments that don't have python2 at all)
* Wed Dec  6 2017 tchvatal@suse.com
- Distribute license file
* Wed Nov 22 2017 arun@gmx.de
- specfile:
  * removed tornado-configtest.patch: fixed upstream
  * update tornado-async-deprecation.patch (partly integrated)
- update to version 4.5.2:
  * Tornado now sets the FD_CLOEXEC flag on all file descriptors it
    creates. This prevents hanging client connections and resource
    leaks when the tornado.autoreload module (or
    Application(debug=True)) is used.
- changes from version 4.5.1:
  * tornado.log
    + Improved detection of libraries for colorized logging.
  * tornado.httputil
    + url_concat once again treats None as equivalent to an empty
    sequence.
- changes from version 4.5.0:
  * long changelog, see http://www.tornadoweb.org/en/stable/releases/v4.5.0.html
    for details
* Tue Oct 17 2017 opensuse_buildservice@ojkastl.de
- added %%{python_module backports.ssl_match_hostname}
  on SLES12 GA aka SP0, to avoid build errors
- explicit BuildRequires for certifi on SLES12 GA aka SP0 only
* Tue Oct 17 2017 opensuse_buildservice@ojkastl.de
- added certifi to BuildRequires, to fix 'ImportError: No module named certifi'
* Wed Aug  9 2017 toddrme2178@gmail.com
- Fix tests
* Fri Jun 23 2017 jmatejek@suse.com
- in %%pre, remove egg-info file if installed, because it's being
  replaced by a directory (bsc#1035604)
* Tue Jun 13 2017 jmatejek@suse.com
- replace the complicated condition for requiring backports.ssl_match_hostname
  with unconditional requirement for Python >= 2.7.9
* Wed May 31 2017 dmueller@suse.com
- require python-backports.ssl_hostname only on python 2.x
* Fri Apr  7 2017 toddrme2178@gmail.com
- update to 4.4.3
  * The `tornado.auth` module has been updated for compatibility with `a
    change to Facebook's access_token endpoint.
* Thu Apr  6 2017 jmatejek@suse.com
- tornado-configtest.patch: fix test failure when __file__ is not absolute
- tornado-async-deprecations.patch: filter test failures due to async
  deprecation warnings, to fix build on python 3.6
- update for multipython build
- enable test suite
* Mon Nov 14 2016 dmueller@suse.com
- update to 4.4.2:
  * Tornado now requires Python 2.7 or 3.3+; versions 2.6 and 3.2 are no
  longer supported. Pypy3 is still supported even though its latest
  release is mainly based on Python 3.2.
  * The `monotonic <https://pypi.python.org/pypi/monotonic>`_ package is
  now supported as an alternative to `Monotime
  <https://pypi.python.org/pypi/Monotime>`_ for monotonic clock support
  on Python 2.
* Wed Dec 23 2015 jmassaguerpla@suse.com
- add singledispatch and backports_abc dependencies
  as stated in docs/releases/v4.3.0.rst
  * Tornado has several new dependencies: (...)
  ``singledispatch`` on all Python versions prior to 3.4 (This was an
  optional dependency in prior versions of Tornado, and is now
  mandatory), and ``backports_abc>=0.4`` on all versions prior to
  3.5
  Since this python module works with python version >= 2.7.9 (otherwise it would be called python3-tornado, afaiu)
* Wed Dec  9 2015 toddrme2178@gmail.com
- Switch to pypi tarball.  It uses "4.3" instead of "4.3.0"
* Tue Dec  8 2015 kkaempf@suse.com
- Update to 4.3.0
  - The new async/await keywords in Python 3.5 are supported.
  Deprecation notice
  - This will be the last release of Tornado to support Python 2.6
    or 3.2.
  See http://www.tornadoweb.org/en/stable/releases/v4.3.0.html
* Sat Oct 17 2015 mc@suse.com
- fix macro
- use package name python-backports-ssl_match_hostname on rhel7
- define py_ver where it does not exist
* Wed Sep 30 2015 fcastelli@suse.com
- python-certifi is an optional depedency when python 2.7.9 is available.
* Sat Sep 26 2015 toddrme2178@gmail.com
- python-certifi is a hard dependency, not an optional one.
* Wed Sep 23 2015 tampakrap@opensuse.org
- Remove python-Twisted BuildRequires. It causes a python-cryptography build
  dependency, which is currently broken on SLE11SP4 due to old OpenSSL version
* Thu Sep 10 2015 aboe76@gmail.com
- Update to 4.2.1:
  Security fix:
  * This release fixes a path traversal vulnerability in StaticFileHandler,
  in which files whose names started with the static_path directory
  but were not actually in that directory could be accessed.
- Update to 4.2:
  Backwards-compatibility:
  * SSLIOStream.connect and IOStream.start_tls now
    validate certificates by default.
  * Certificate validation will now use the system CA root certificates
    instead of certifi when possible (i.e. Python 2.7.9+ or 3.4+).
    This includes IOStream and simple_httpclient, but not curl_httpclient
  * The default SSL configuration has become stricter,
    using ssl.create_default_context where available on the client side.
    (On the server side, applications are encouraged to migrate from
    the ssl_options dict-based API to pass an ssl.SSLContext instead).
  * The deprecated classes in the tornado.auth module, GoogleMixin,
    FacebookMixin, and FriendFeedMixin have been removed.
  * see more details:
    http://www.tornadoweb.org/en/stable/releases/v4.2.0.html
* Wed Aug 12 2015 seife+obs@b1-systems.com
- fix build with non-SUSE distributions
* Wed Apr 22 2015 mcihar@suse.cz
- Update to 4.1:
  * If a `.Future` contains an exception but that exception is never
    examined or re-raised (e.g. by yielding the `.Future`), a stack
    trace will be logged when the `.Future` is garbage-collected.
  * New class `tornado.gen.WaitIterator` provides a way to iterate
    over ``Futures`` in the order they resolve.
  * The `tornado.websocket` module now supports compression via the
    "permessage-deflate" extension.  Override
    `.WebSocketHandler.get_compression_options` to enable on the server
    side, and use the ``compression_options`` keyword argument to
    `.websocket_connect` on the client side.
  * When the appropriate packages are installed, it is possible to yield
    `asyncio.Future` or Twisted ``Defered`` objects in Tornado coroutines.
* Thu Oct  2 2014 toddrme2178@gmail.com
- Remove python-pycares BuildRequires since it is optional and
  not in openSUSE:Factory
* Wed Oct  1 2014 toddrme2178@gmail.com
- Update to version 4.0.2
  + Bug fixes
  * Fixed a bug that could sometimes cause a timeout to fire after being
    cancelled.
  * `.AsyncTestCase` once again passes along arguments to test methods,
    making it compatible with extensions such as Nose's test generators.
  * `.StaticFileHandler` can again compress its responses when gzip is enabled.
  * ``simple_httpclient`` passes its ``max_buffer_size`` argument to the
    underlying stream.
  * Fixed a reference cycle that can lead to increased memory consumption.
  * `.add_accept_handler` will now limit the number of times it will call
    `~socket.socket.accept` per `.IOLoop` iteration, addressing a potential
    starvation issue.
  * Improved error handling in `.IOStream.connect` (primarily for FreeBSD
    systems)
- Update to version 4.0.1
  + Bug fixes
  * The build will now fall back to pure-python mode if the C extension
    fails to build for any reason (previously it would fall back for some
    errors but not others).
  * `.IOLoop.call_at` and `.IOLoop.call_later` now always return
    a timeout handle for use with `.IOLoop.remove_timeout`.
  * If any callback of a `.PeriodicCallback` or `.IOStream` returns a
    `.Future`, any error raised in that future will now be logged
    (similar to the behavior of `.IOLoop.add_callback`).
  * Fixed an exception in client-side websocket connections when the
    connection is closed.
  * ``simple_httpclient`` once again correctly handles 204 status
    codes with no content-length header.
  * Fixed a regression in ``simple_httpclient`` that would result in
    timeouts for certain kinds of errors.
- Update to version 4.0.0
  + Highlights
  * The `tornado.web.stream_request_body` decorator allows large files to be
    uploaded with limited memory usage.
  * Coroutines are now faster and are used extensively throughout Tornado itself.
    More methods now return `Futures <.Future>`, including most `.IOStream`
    methods and `.RequestHandler.flush`.
  * Many user-overridden methods are now allowed to return a `.Future`
    for flow control.
  * HTTP-related code is now shared between the `tornado.httpserver`,
    ``tornado.simple_httpclient`` and `tornado.wsgi` modules, making support
    for features such as chunked and gzip encoding more consistent.
    `.HTTPServer` now uses new delegate interfaces defined in `tornado.httputil`
    in addition to its old single-callback interface.
  * New module `tornado.tcpclient` creates TCP connections with non-blocking
    DNS, SSL handshaking, and support for IPv6.
  + See more release details at
    http://www.tornadoweb.org/en/stable/releases/v4.0.0.html
- Update to version 3.2.2
  + Security fixes
  * The XSRF token is now encoded with a random mask on each request.
    This makes it safe to include in compressed pages without being
    vulnerable to the `BREACH attack <http://breachattack.com>`_.
    This applies to most applications that use both the ``xsrf_cookies``
    and ``gzip`` options (or have gzip applied by a proxy).
  + Backwards-compatibility notes
  * If Tornado 3.2.2 is run at the same time as older versions on the same
    domain, there is some potential for issues with the differing cookie
    versions.  The `.Application` setting ``xsrf_cookie_version=1`` can
    be used for a transitional period to generate the older cookie format
    on newer servers.
  + Other changes
  * ``tornado.platform.asyncio`` is now compatible with ``trollius`` version 0.3.
* Tue May 20 2014 toddrme2178@gmail.com
- Update dependencies
* Sun May 11 2014 andrea@opensuse.org
- new upstream version 3.2.1
  - several new modules and bugfixes check website for details
    http://www.tornadoweb.org/en/stable/releases.html
* Sun Nov 17 2013 p.drouand@gmail.com
- Update to version 3.1.1
  + StaticFileHandler no longer fails if the client requests a Range that
    is larger than the entire file (Facebook has a crawler that does this).
  + RequestHandler.on_connection_close now works correctly on subsequent
    requests of a keep-alive connection.
* Thu Aug 15 2013 speilicke@suse.com
- Update to version 3.1:
  + See http://www.tornadoweb.org/en/stable/releases/v3.1.0.html
- Fix rpmlint issues properly
- Use upstream URL
* Thu Apr 11 2013 alexandre@exatati.com.br
- Update to 3.0.1:
  - The interface of tornado.auth.FacebookGraphMixin is now
    consistent with its documentation and the rest of the module.
    The get_authenticated_user and facebook_request methods return
    a Future and the callback argument is optional.
  - The tornado.testing.gen_test decorator will no longer be
    recognized as a (broken) test by nose.
  - Work around a bug in Ubuntu 13.04 betas involving an
    incomplete backport of the ssl.match_hostname function.
  - tornado.websocket.websocket_connect now fails cleanly when it
    attempts to connect to a non-websocket url.
  - tornado.testing.LogTrapTestCase once again works with byte
    strings on Python 2.
  - The request attribute of tornado.httpclient.HTTPResponse is
    now always an HTTPRequest, never a _RequestProxy.
  - Exceptions raised by the tornado.gen module now have better
    messages when tuples are used as callback keys.
* Sat Mar 30 2013 alexandre@exatati.com.br
- Update to 3.0:
  - Please read full changelog at
    http://www.tornadoweb.org/en/stable/releases/v3.0.0.html
* Sun Nov 25 2012 alexandre@exatati.com.br
- Update to 2.4.1:
  - Fixed a memory leak in tornado.stack_context that was especially
    likely with long-running @gen.engine functions.
  - tornado.auth.TwitterMixin now works on Python 3.
  - Fixed a bug in which IOStream.read_until_close with a streaming
    callback would sometimes pass the last chunk of data to the
    final callback instead of the streaming callback.
* Wed Sep  5 2012 alexandre@exatati.com.br
- Update to 2.4:
  - Please check changelog at
    http://www.tornadoweb.org/documentation/releases/v2.4.0.html
* Fri Jun  1 2012 alexandre@exatati.com.br
- Update to 2.3:
  - Please check changelog at
    http://www.tornadoweb.org/documentation/releases/v2.3.0.html
* Fri May 18 2012 toddrme2178@gmail.com
- Fix rpmlint warnings
- Improve openSUSE 11.4 build fix
- Clean up spec file
* Mon Apr 30 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4 x86_64
* Sat Apr 28 2012 highwaystar.ru@gmail.com
- added python3 package
* Tue Apr 24 2012 alexandre@exatati.com.br
- Update to 2.2.1:
  - tornado.web.RequestHandler.set_header now properly sanitizes
    input values to protect against header injection, response
    splitting, etc. (it has always attempted to do this, but the
    check was incorrect). Note that redirects, the most likely
    source of such bugs, are protected by a separate check in
    RequestHandler.redirect.
  - Colored logging configuration in tornado.options is compatible
    with Python 3.2.3 (and 3.3).
* Wed Mar 21 2012 saschpe@gmx.de
- Update requires on python-curl to python-pycurl
* Mon Mar 12 2012 saschpe@gmx.de
- Simplified macro usage
- Use upstream tarball
* Mon Jan 30 2012 alexandre@exatati.com.br
- Update to 2.2:
  - Please read http://www.tornadoweb.org/documentation/releases/v2.2.0.html
    for all changes in this release.
* Tue Oct  4 2011 alexandre@exatati.com.br
- Update to 2.1.1
  Bug fixes:
  - Fixed handling of closed connections with the epoll
    (i.e. Linux) IOLoop. Previously, closed connections could be
    shut down too early, which most often manifested as “Stream
    is closed” exceptions in SimpleAsyncHTTPClient.
  - Fixed a case in which chunked responses could be closed
    prematurely, leading to truncated output.
  - IOStream.connect now reports errors more consistently via
    logging and the close callback (this affects e.g. connections
    to localhost on FreeBSD).
  - IOStream.read_bytes again accepts both int and long arguments.
  - PeriodicCallback no longer runs repeatedly when IOLoop
    iterations complete faster than the resolution of time.time()
    (mainly a problem on Windows).
  Backwards-compatibility note
  - Listening for IOLoop.ERROR alone is no longer sufficient for
    detecting closed connections on an otherwise unused socket.
    IOLoop.ERROR must always be used in combination with READ or
    WRITE.
* Wed Sep 21 2011 alexandre@exatati.com.br
- Update to 2.1:
  - There are security fixes, backwards-incompatible changes,
    new modules, and bug fixes.
  For full changes please read
  http://www.tornadoweb.org/documentation/releases/v2.1.0.html
* Thu Jul  7 2011 saschpe@gmx.de
- Added README and examples to documentation
- Fixed license string to "Apache-2.0"
* Wed Jun 22 2011 alexandre@exatati.com.br
- Update to 2.0:
  Major changes:
  * Template output is automatically escaped by default; see backwards
    compatibility note below.
  * The default AsyncHTTPClient implementation is now simple_httpclient.
  * Python 3.2 is now supported.
  For backwards compatibility and other changes in this release,
  please read http://www.tornadoweb.org/documentation/releases/v2.0.0.html
- Regenerate spec file with py2pack.
* Fri Mar  4 2011 alexandre@exatati.com.br
- Update to 1.2.1.
* Sun Feb 20 2011 alexandre@exatati.com.br
- Update to 1.2.
* Wed Feb  9 2011 alexandre@exatati.com.br
- Update to 1.1.1.
* Fri Sep 10 2010 alexandre@exatati.com.br
- Update to 1.1.
* Tue May 18 2010 alexandre@exatati.com.br
- New tarball release on PyPI.
* Fri Nov 13 2009 alexandre@exatati.com.br
- Update to 0.2;
- Building as noarch for openSUSE >= 11.2.
* Mon Sep 14 2009 alexandre@exatati.com.br
- Initial package (0.1) for openSUSE.
